@@ -216,7 +216,7 @@ class split_test(object):
         Z = X.copy()
         n_sample = len(Z)
 
-        if len(self.inf_feats[k]) > 1:
+        if len(self.inf_feats[k].shape) > 1:
             ## for channels_last image data: shape should be (#samples, img_rows, img_cols, channel)
             if len(cat_feats):
                 warnings.warn("cat_feats is ignored. cat_feats only works for tabular data, whereas a image dataset is given.")
@@ -245,7 +245,7 @@ class split_test(object):
          k-th hypothesized features in inf_feats
         """
         Z = X.copy()
-        if type(self.inf_feats[k]) is list:
+        if len(self.inf_feats[k].shape) > 1:
             ## for channels_last image data: shape should be (#samples, img_rows, img_cols, channel)
             Z[:,self.inf_feats[k][0][:,None], self.inf_feats[k][1], :]= np.random.permutation(Z[:,self.inf_feats[k][0][:,None], self.inf_feats[k][1], :])
         else:
